@@ -1,142 +1,8 @@
-"""Identifying titrable sites and integrity checking functions
-"""
 from copy import copy
-
 from pypka.config import Config
 from pypka.constants import *
-
 from pypka.clean.ffconverter import main_chains, CHARMM_protomers
-from pypka.clean.formats import new_pdb_line, read_gro_line, read_pdb_line
-
-
-def identify_tit_sites(molecules, instanciate_sites=True):
-    def SitesFileLine(chain, resnumb, resname):
-        for res in REGULARTITRATINGRES:
-            if res[0:2] == resname[0:2]:
-                resname = res
-        if resname in TITRABLETAUTOMERS:
-            ntautomers = TITRABLETAUTOMERS[resname]
-        else:
-            for res in REGULARTITRATINGRES:
-                if res[0:2] == resname[0:2]:
-                    ntautomers = TITRABLETAUTOMERS[res]
-        # In debug mode, a .sites file is created
-        text = "{0} ".format(resnumb)
-        for i in range(ntautomers):
-            text += "{0}tau{1} ".format(resname, i + 1)
-
-        if resname in ("NTR", "CTR"):
-            chain_res[chain][str(resnumb)] = resname
-            resnumb += TERMINAL_OFFSET
-        else:
-            chain_res[chain][resnumb] = resname
-
-        if instanciate_sites:
-            instanciate_site(resnumb, resname, ntautomers)
-
-        return text + "\n"
-
-    def instanciate_site(resnumb, resname, ntautomers):
-        sID = molecule.addSite(resnumb)
-        molecule.addTautomers(sID, ntautomers, resname)
-
-    sites_file = ""
-    sites = {chain: [] for chain in molecules.keys()}
-    chain_res = {chain: {} for chain in molecules.keys()}
-    skip_NTR = {chain: False for chain in molecules.keys()}
-    last_res = None
-    with open(Config.pypka_params["f_in"]) as f:
-        nline = 0
-        resnumb = None
-        resname = None
-        for line in f:
-            nline += 1
-            if "ATOM " == line[0:5]:
-                (aname, anumb, resname, chain, resnumb, x, y, z) = read_pdb_line(line)
-                insertion_code = line[26].strip()
-                if insertion_code:
-                    continue
-
-                last_res = resnumb
-                last_chain = chain
-                chain_sites = []
-
-                if chain in molecules.keys():
-                    molecule = molecules[chain]
-                    chain_sites = chain_res[chain]
-
-                    if Config.pypka_params["ffinput"] == "CHARMM":
-                        for can_res, charmm_res in CHARMM_protomers.items():
-                            if resname in charmm_res:
-                                resname = can_res
-
-                    if resname in PROTEIN_RESIDUES or resname in TITRABLERESIDUES:
-                        if resnumb not in chain_sites:
-                            if not chain_res[chain] and not skip_NTR[chain]:
-                                if resname == "PRO":
-                                    skip_NTR[chain] = True
-                                    continue
-                                sites_file += SitesFileLine(chain, resnumb, "NTR")
-                                # add2chain(chain, chain_res, str(resnumb), "NTR")
-                                if instanciate_sites:
-                                    molecule.NTR = resnumb
-
-                            if (
-                                resname in TITRABLERESIDUES
-                                and resname != "NTR"
-                                and resname != "CTR"
-                            ):
-                                if (
-                                    Config.pypka_params["ser_thr_titration"] == False
-                                    and resname in ("SER", "THR")
-                                ) or (
-                                    Config.pypka_params["ffID"] == "CHARMM36m"
-                                    and resname in ("SER", "THR")
-                                ):
-                                    continue
-                                sites_file += SitesFileLine(chain, resnumb, resname)
-                                # add2chain(chain, chain_res, resnumb, resname)
-
-                        if "CTR" not in sites and aname in (
-                            "CT",
-                            "OT",
-                            "OT1",
-                            "OT2",
-                            "O1",
-                            "O2",
-                            "OXT",
-                        ):
-                            sites_file += SitesFileLine(chain, resnumb, "CTR")
-                            # add2chain(chain, chain_res, str(resnumb), "CTR")
-                            if instanciate_sites:
-                                molecule.CTR = resnumb
-
-    if (
-        "CTR" not in sites
-        and aname in ("CT", "OT", "OT1", "OT2", "O1", "O2", "OXT")
-        and molecule.sites == "all"
-    ):
-        sites_file += SitesFileLine(chain, last_res, "CTR")
-        # add2chain(last_chain, chain_res, str(last_res), "CTR")
-        if instanciate_sites:
-            molecule.CTR = resnumb
-
-    if not chain_res and instanciate_sites:
-        f_in = Config.pypka_params["f_in"]
-        raise Exception("Not one titrable residue was found in {}".format(f_in))
-
-    if instanciate_sites:
-        for molecule in molecules.values():
-            # Adding the reference tautomer to each site
-            molecule.addReferenceTautomers()
-            # Assigning a charge set to each tautomer
-            molecule.addTautomersChargeSets()
-
-    if Config.debug:
-        with open("tmp.sites", "w") as f_new:
-            f_new.write(sites_file)
-
-    return chain_res
+from pdbmender.formats import new_pdb_line, read_gro_line, read_pdb_line
 
 
 def check_sites_integrity(molecules, chains_res, useTMPpdb=False):
@@ -641,15 +507,3 @@ def fix_fixed_sites(molecules, fixed_sites, fname):
                 new_pdb_content += line
     with open(fname, "w") as f:
         f.write(new_pdb_content)
-
-
-def get_chains_from_file(f_in):
-    chain_list = []
-    with open(f_in) as f:
-        for line in f:
-            if "ATOM " == line[0:5]:
-                (aname, anumb, resname, chain, resnumb, x, y, z) = read_pdb_line(line)
-                if chain not in chain_list:
-                    chain_list.append(chain)
-
-    return chain_list
