@@ -1,21 +1,34 @@
 import os
 from copy import copy
-import subprocess
 
 from pypka.config import Config
-from pypka.constants import *
+from pypka.constants import (
+    LIPID_RESIDUES,
+    NUCLEIC_ACIDS,
+    RNA_RESIDUES,
+    PDB_RNA_RESIDUES,
+    IONS,
+    TERMINAL_OFFSET,
+    TITRABLETAUTOMERS,
+    PROTEIN_RESIDUES,
+    TITRABLERESIDUES,
+)
 
-from pypka.clean.ffconverter import *
-from pypka.clean.formats import (
-    correct_names,
+from pypka.clean.ffconverter import mainchain_Hs, AMBER_Hs, AMBER_mainchain_Hs
+from pdbmender.formats import (
     new_gro_line,
     new_pdb_line,
-    new_pqr_line,
-    pdb2gro,
     read_gro_line,
     read_pdb_line,
     read_pqr_line,
 )
+from pdbmender.utils import (
+    mend_pdb,
+    prepare_for_addHtaut,
+    add_tautomers,
+    rm_cys_bridges,
+    identify_cter,
+)
 
 
 def inputPDBCheck(filename, sites, clean_pdb):
@@ -163,6 +176,45 @@ def inputPDBCheck(filename, sites, clean_pdb):
     return chains_length, chains_res
 
 
+def get_pdb_Hs(pdbname, chains_res):
+    with open(pdbname) as f:
+        content = f.readlines()
+    for line in content:
+        if line.startswith("ATOM "):
+            (
+                aname,
+                anumb,
+                resname,
+                chain,
+                resnumb,
+                x,
+                y,
+                z,
+                _,
+                _,
+            ) = read_pqr_line(line)
+
+            if chain not in chains_res:
+                continue
+            elif (
+                chain in chains_res
+                and resnumb in chains_res[chain]
+                and resname in AMBER_Hs
+                and aname in AMBER_Hs[resname]
+                and aname not in AMBER_mainchain_Hs
+            ):
+                continue
+            elif aname[0] == "H" and aname not in ("H1", "H2", "H3"):
+                if not chain in mainchain_Hs:
+                    mainchain_Hs[chain] = {}
+                if not resnumb in mainchain_Hs[chain]:
+                    mainchain_Hs[chain][resnumb] = []
+                mainchain_Hs[chain][resnumb].append(
+                    (aname, anumb, resname, chain, x, y, z)
+                )
+    return mainchain_Hs
+
+
 def cleanPDB(molecules, chains_res, inputpqr, outputpqr, automatic_sites):
 
     pdb_filename = Config.pypka_params["f_in"]
@@ -176,258 +228,76 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr, automatic_sites):
 
     logfile = "LOG_pdb2pqr"
 
-    rna_inputpqr = "clean_rna.pqr"
-    logfile_rna = "LOG_pdb2pqr_rna"
-
     # CTR O1/O2 will be deleted and a O/OXT will be added
     # CYS will be turned into CY0
     # All HIS will become fully protonated
-    os.system(
-        "python2 {0} {1} {2} --ff {3} --ffout {4} "
-        "--drop-water -v --chain {6} > {5} 2>&1 ".format(
-            Config.pypka_params["pdb2pqr"],
-            Config.pypka_params["pdb2pqr_inputfile"],
-            inputpqr,
-            Config.pypka_params["ffinput"],
-            Config.pypka_params["ff_family"],
-            logfile,
-            "" if Config.pypka_params["pdb2pqr_h_opt"] else "--noopt",
-        )
+    mend_pdb(
+        Config.pypka_params["pdb2pqr_inputfile"],
+        inputpqr,
+        Config.pypka_params["ffinput"],
+        Config.pypka_params["ff_family"],
+        logfile=logfile,
+        hopt=Config.pypka_params["pdb2pqr_h_opt"],
     )
 
-    CYS_bridges = get_cys_bridges(logfile, molecules)
+    chains_res, cys_bridges = rm_cys_bridges(chains_res, logfile)
+    for chain in cys_bridges.keys():
+        molecule = molecules[chain]
+        molecule.saveCYSBridges(cys_bridges[chain])
 
     if automatic_sites:
-        chains_res = identify_cter(inputpqr, molecules, chains_res)
+        old_ctrs = {}
+        for chain in chains_res:
+            for resnumb, resname in chains_res[chain].items():
+                old_ctrs[chain] = None
+                if isinstance(resnumb, str) and resname == "CTR":
+                    old_ctrs[chain] = int(resnumb)
+
+        new_ctrs = identify_cter(inputpqr, old_ctrs)
+
+        for chain, resnumb in new_ctrs.items():
+            chains_res[chain][str(resnumb)] = "CTR"
+            molecules[chain].CTR = resnumb
+            sID = molecules[chain].addSite(resnumb + TERMINAL_OFFSET)
+            molecules[chain].addTautomers(sID, TITRABLETAUTOMERS["CTR"], "CTR")
 
     if Config.pypka_params["f_structure_out"]:
+        hs_pdb = "Hs.pqr"
         ff_out = Config.pypka_params["ff_structure_out"]
         if ff_out == "gromos_cph":
             ff_out = "gromos"
-        os.system(
-            "python2 {0} {1} Hs.pqr --ff {3} --ffout {3} "
-            "--drop-water -v --chain >> {2} 2>&1 ".format(
-                Config.pypka_params["pdb2pqr"],
-                Config.pypka_params["pdb2pqr_inputfile"],
-                logfile,
-                ff_out,
-            )
+        mend_pdb(
+            Config.pypka_params["pdb2pqr_inputfile"],
+            hs_pdb,
+            ff_out,
+            ff_out,
+            logfile=logfile,
         )
+        get_pdb_Hs(hs_pdb, chains_res)
 
-    if Config.pypka_params["f_structure_out"]:
-        with open("Hs.pqr") as f:
-            for line in f:
-                if line.startswith("ATOM "):
-                    (
-                        aname,
-                        anumb,
-                        resname,
-                        chain,
-                        resnumb,
-                        x,
-                        y,
-                        z,
-                        charge,
-                        radius,
-                    ) = read_pqr_line(line)
+    sites = {
+        chain: list(molecule.sites.keys()) for chain, molecule in molecules.items()
+    }
+    termini = {
+        chain: (molecule.NTR, molecule.CTR) for chain, molecule in molecules.items()
+    }
 
-                    if chain not in chains_res:
-                        continue
-                    elif (
-                        chain in chains_res
-                        and resnumb in chains_res[chain]
-                        and resname in AMBER_Hs
-                        and aname in AMBER_Hs[resname]
-                        and aname not in AMBER_mainchain_Hs
-                    ):
-                        continue
-                    elif aname[0] == "H" and aname not in ("H1", "H2", "H3"):
-                        if not chain in mainchain_Hs:
-                            mainchain_Hs[chain] = {}
-                        if not resnumb in mainchain_Hs[chain]:
-                            mainchain_Hs[chain][resnumb] = []
-                        mainchain_Hs[chain][resnumb].append(
-                            (aname, anumb, resname, chain, x, y, z)
-                        )
-
-    new_pdb_text = ""
-    removed_pdb_text = ""
-    removed_pdb_lines = []
-    # ntr_trigger = True
-    resnumb_max = 0
-    chains = list(molecules.keys())
-
-    with open(inputpqr) as f:
-        NUCLEIC_ACIDS = list(DNA_RESIDUES.values()) + list(RNA_RESIDUES.values())
-        for line in f:
-            if "ATOM" in line[:4]:
-                (
-                    aname,
-                    anumb,
-                    resname,
-                    chain,
-                    resnumb,
-                    x,
-                    y,
-                    z,
-                    charge,
-                    radius,
-                ) = read_pqr_line(line)
-
-                termini_trigger = False
-
-                if chain in chains:
-                    molecule = molecules[chain]
-                    NTR_numb = molecule.NTR
-                    CTR_numb = molecule.CTR
-
-                    sites_numbs = molecule.sites.keys()
-
-                    aname, resname = correct_names(
-                        resnumb, resname, aname, sites_numbs, NTR_numb, CTR_numb
-                    )
-                    resnumb_max = resnumb
-
-                    # if resname == "CY0":
-                    #    resname = "CYS"
-                    #    if aname == "HG1":
-                    #        continue
-
-                    if resnumb in (NTR_numb, CTR_numb):
-                        termini_trigger = True
-
-                if resname == "CYS":
-                    change_atoms = {"1CB": "CB", "1SG": "SG"}
-                    if aname in change_atoms.keys():
-                        aname = change_atoms[aname]
-                if (
-                    aname in ("O1", "O2", "OT1", "OT2", "H1", "H2", "H3")
-                    and not termini_trigger
-                    and resname in PROTEIN_RESIDUES
-                ):
-                    if aname == "O1":
-                        aname = "O"
-                    elif aname == "H1":
-                        aname = "H"
-                    else:
-                        continue
-
-                if line[26] != " ":
-                    resnumb += TERMINAL_OFFSET
-
-                new_line = new_pqr_line(
-                    anumb,
-                    aname,
-                    resname,
-                    resnumb,
-                    x,
-                    y,
-                    z,
-                    charge,
-                    radius,
-                    chain=chain,
-                )
-                if chain in molecules:
-                    new_pdb_text += new_line
-                elif (
-                    aname not in ("O1", "O2", "OT1", "OT2", "H1", "H2", "H3")
-                    or resname in NUCLEIC_ACIDS
-                ):
-                    if resname in ("SER", "THR") and aname == "HG1":
-                        aname = "HG"
-                    removed_pdb_lines.append(new_line)
-
-    resnumb_old = resnumb_max + 1
-    for line in removed_pdb_lines:
-        (
-            aname,
-            anumb_old,
-            resname,
-            chain,
-            resnumb,
-            x,
-            y,
-            z,
-            charge,
-            radius,
-        ) = read_pqr_line(line)
-        anumb += 1
-        resnumb += resnumb_old
-        while resnumb < resnumb_max:
-            resnumb += resnumb_old
-        removed_pdb_text += new_pqr_line(
-            anumb, aname, resname, resnumb, x, y, z, charge, radius, chain=chain
-        )
-        resnumb_max = resnumb
-    #            if ntr_trigger and :
-    #                config.tit_mole._NTR = resnumb
-
-    # chains = copy(chains_res['A'])
-    # for res in chains:
-    #    if str(res) > config.terminal_offset:
-    #        print((res, chains_res['A'][res]))
-    #        del chains_res['A'][res]
-    # chains_res['A'][config.tit_mole._NTR] = 'NTR'
-    # chains_res['A'][config.tit_mole._CTR] = 'CTR'
-
-    with open("cleaned.pqr", "w") as f_new:
-        f_new.write(new_pdb_text)
-
-    with open("removed.pqr", "w") as f_new:
-        f_new.write(removed_pdb_text)
-
-    sites_addHtaut = ""
-    for chain in molecules:
-        for res in chains_res[chain]:
-            if chains_res[chain][res] == "NTR" or (
-                chain in CYS_bridges and res in CYS_bridges[chain]
-            ):
-                continue
-            sites_addHtaut += "{0}--{1}--{2},".format(
-                res, chains_res[chain][res], chain.replace(" ", "_")
-            )
-
-    if len(sites_addHtaut) > 0 and sites_addHtaut[-1] == ",":
-        sites_addHtaut = sites_addHtaut[:-1]
-
-    if len(sites_addHtaut.strip()) == 0:
-        os.system("cp cleaned.pqr {}".format(outputpqr))
-
-    else:
-        logfile = "LOG_addHtaut"
-        script_dir = os.path.dirname(os.path.abspath(__file__))
-
-        # TODO rewrite addHtaut as python module
-        try:
-            cmd = "{}/addHtaut cleaned.pqr {} {} > {}".format(
-                script_dir,
-                Config.pypka_params["ff_family"],
-                sites_addHtaut,
-                outputpqr,
-                logfile,
-            )
-            addhtaut_run = subprocess.run(
-                cmd,
-                shell=True,
-                check=True,
-                stdout=subprocess.PIPE,
-                stderr=subprocess.PIPE,
-            )
-        except subprocess.CalledProcessError as e:
-            raise Exception(
-                "addHtaut did not run successfully\nMessage: {}".format(
-                    e.stderr.decode("ascii")
-                )
-            )
+    to_exclude = NUCLEIC_ACIDS
+    nontitrating_lines = add_tautomers(
+        inputpqr,
+        chains_res,
+        Config.pypka_params["ff_family"],
+        outputpqr,
+        to_exclude=to_exclude,
+        terminal_offset=TERMINAL_OFFSET,
+    )
 
     with open(outputpqr) as f:
         content = f.read()
     with open(outputpqr, "w") as f_new:
-        f_new.write(content + removed_pdb_text)
+        f_new.write(content + nontitrating_lines)
 
     rna_pqr = None
-    # if rna_file:
-    #    rna_pqr = rna_inputpqr
     final_pdb = "TMP.pdb"
     write_final_pdb(pdb_filename, outputpqr, final_pdb, rna_pqr)
 
@@ -463,66 +333,6 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr, automatic_sites):
         os.remove(Config.pypka_params["pdb2pqr_inputfile"])
 
 
-def get_cys_bridges(f_pdb2pqr_log, molecules):
-    CYS_bridges = {}
-    with open(f_pdb2pqr_log) as f:
-        trigger_error = ""
-        for line in f:
-            if "patched with CYX" in line:
-                parts = line.split("patched")[0].replace("PATCH INFO: ", "").split()
-                resname, chain, resnumb = parts
-                # chain = chain.replace("_", " ")
-                if not chain in CYS_bridges:
-                    CYS_bridges[chain] = []
-                cys_res_numb = int(parts[-1])
-                if cys_res_numb not in CYS_bridges[chain]:
-                    CYS_bridges[chain].append(cys_res_numb)
-            if (
-                "error" in line.lower()
-                and "Error parsing line: invalid literal for int() with base 10"
-                not in line
-            ):
-                trigger_error += line
-        if trigger_error:
-            raise Exception(
-                "Found errors while parsing the input structure to PDB2PQR:\n"
-                + trigger_error
-            )
-
-    for chain, molecule in molecules.items():
-        if chain in CYS_bridges:
-            molecule.saveCYSBridges(CYS_bridges[chain])
-    return CYS_bridges
-
-
-def identify_cter(inputpqr, molecules, chains_res):
-    with open(inputpqr) as f:
-        for line in f:
-            if line.startswith("ATOM "):
-                (aname, anumb, resname, chain, resnumb, x, y, z) = read_pdb_line(line)
-                if (
-                    "CTR" not in chains_res
-                    and aname
-                    in (
-                        "CT",
-                        "OT",
-                        "OT1",
-                        "OT2",
-                        "O1",
-                        "O2",
-                        "OXT",
-                    )
-                    and chain in chains_res
-                    and str(resnumb) not in chains_res[chain]
-                    and resname in [*TITRABLERESIDUES, *PROTEIN_RESIDUES]
-                ):
-                    chains_res[chain][str(resnumb)] = "CTR"
-                    molecules[chain].CTR = resnumb
-                    sID = molecules[chain].addSite(resnumb + TERMINAL_OFFSET)
-                    molecules[chain].addTautomers(sID, TITRABLETAUTOMERS["CTR"], "CTR")
-    return chains_res
-
-
 def remove_membrane_n_rna(pdbfile, outfile):
     protein_lines = ""
     to_remove = LIPID_RESIDUES + list(Config.pypka_params.LIPIDS.values())
@@ -569,18 +379,7 @@ def remove_membrane_n_rna(pdbfile, outfile):
 def write_final_pdb(pdb_filename, outputpqr, final_pdb, rna_inputpqr):
     def pqr2pdb(line, counter):
         counter += 1
-        (
-            aname,
-            anumb_old,
-            resname,
-            chain,
-            resnumb,
-            x,
-            y,
-            z,
-            charge,
-            radius,
-        ) = read_pqr_line(line)
+        (aname, anumb_old, resname, chain, resnumb, x, y, z) = read_pdb_line(line)
 
         # if chain == "_":
         #    chain = " "
